@@ -1,8 +1,6 @@
 import os
 from pathlib import Path
 
-from dotenv import load_dotenv
-
 ROOT_DIR = Path(
     os.getenv(
         "ROOT_DIR", Path(os.path.dirname(os.path.abspath(__file__))) / ".."
@@ -27,6 +25,14 @@ PATH2CCAM = DIR2RESOURCES / "ccam_hierarchy.csv"
 PATH2ICD10_CHAPTERS = DIR2RESOURCES / "icd10_chapters.csv"
 PATH2IR_PHA = DIR2RESOURCES / "IR_PHA_R.csv"
 
+# Path to exported embeddings
+PATH2SNDS_EMBEDDINGS = (
+    DIR2DATA
+    / "results"
+    / "snds"
+    / "echantillon_mid_grain_r=90-centered2019-12-05_19:11:27.parquet"
+)
+
 # event models columns
 COLNAME_PERSON = "person_id"
 COLNAME_STAY_ID = "visit_occurrence_id"
@@ -40,3 +46,8 @@ COLNAME_QUALIFIER = "qualifier_concept_id"
 COLNAME_VALUE = "value"
 COLNAME_UNIT = "unit_concept_id"
 COLNAME_UNIT_SOURCE = "unit_source_value"
+
+# other columns names
+COLNAME_FOLLOWUP_START = "followup_start"
+OBSERVATION_START = "observation_start"
+OBSERVATION_END = "observation_end"
